@@ -32,7 +32,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 use UI::Various::core;
 use UI::Various::Listbox;
@@ -91,8 +91,6 @@ sub _prepare($$$)
 	error('_1_element_must_be_accompanied_by_parent', __PACKAGE__);
 	return 1;
     }
-#    my @width =
-#	($self->width < $self->top->max_width ? (-width => $self->width) : ());
     $self->_cui($_->_cui
 		->add($self->_cid,
 		      'Listbox', -x => $column, -y => $row,
@@ -101,6 +99,10 @@ sub _prepare($$$)
 		      -width => $self->width + 2,
 		      -multi => $self->selection == 2,
 		      -onchange => sub {
+			  defined $self->{on_select}  and
+			      # onchange is also called via _remove!
+			      not defined $self->{no_on_select}  and
+			      &{$self->{on_select}};
 			  return 0;
 		      },
 		      -vscrollbar => 1,
@@ -149,7 +151,9 @@ sub _remove($$)
 	sort { $a <=> $b }
 	keys %selected;
     $self->_cui->clear_selection();
+    defined $self->{on_select}  and  $self->{no_on_select} = 1;
     $self->_cui->set_selection(@selected);
+    defined $self->{on_select}  and  delete $self->{no_on_select};
     $self->_cui->intellidraw();
 }
 
